@@ -29,13 +29,7 @@ require DynaLoader;
 
 our @ISA = qw(Exporter DynaLoader);
 
-#our %EXPORT_TAGS = ( 'all' => [ qw() ] );
-
-#our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-#our @EXPORT = qw();
-
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 bootstrap Win32::PerfMon $VERSION;
 
@@ -59,6 +53,7 @@ sub new
 	$self->{'COUNTERS'} = undef;
 	$self->{'ERRORMSG'} = undef;
 	$self->{'MACHINENAME'} = undef;
+	$self->{'CALC_RATE'} = 0;
 	
 	bless($self, $class);
 	
@@ -108,6 +103,11 @@ sub AddCounter
 	}
 	
 	my ($self, $ObjectName, $CounterName, $InstanceName) = @_;
+	
+	if($CounterName =~ /\/sec/g)
+	{
+		$self->{'CALC_RATE'} = 1;
+	}
 				
 	# go and create the counter ....
         my $NewCounter = add_counter($ObjectName, $CounterName, $InstanceName, $self->{'HQUERY'}, $self->{'ERRORMSG'});
@@ -138,6 +138,14 @@ sub CollectData
 	# Populate the counters associated witht he query object
 	my $res = collect_data($self->{'HQUERY'}, $self->{'ERRORMSG'});
 	
+	if($self->{'CALC_RATE'} == 1 && ($res != -1))
+	{	
+		sleep(1);
+
+		$res = collect_data($self->{'HQUERY'}, $self->{'ERRORMSG'});
+	}
+	
+	
 	if($res == -1)
 	{
 	    return(0);
@@ -146,6 +154,12 @@ sub CollectData
 	{
 	    return(1);
 	}
+	
+	
+	
+	
+	
+
 }
 
 ##########################################
@@ -319,9 +333,25 @@ This function adds the requested counter to the query obejct.
 Not all counters will have a Instance.  This this case, you would simply substitue the 
 Instance with a -1.
 
-This function can be called as many times as is needed, to gather the requested counters.
+If you require performance data onmultiple counter, simply call AddCounter() multiple time, prior
+to calling collect data
 
+        # Create the object
+        my $PerfObj = Win32::PerfMon->new("\\\\SERVERNAME");
+
+        # Add All the counters
 	$PerfObj->AddCounter("System", "System Up Time", -1);
+	$PerfObj->AddCounter("System","Context Switches/sec", "-1");
+        $PerfObj->AddCounter("System","Processes", "-1");
+        $PerfObj->AddCounter("Processor","Interrupts/sec", "_Total");
+        
+        # Populate the counters from perfmon
+        $PerfObj->CollectData()
+        
+        # Now retrieve the data
+        my $value = $PerfObj->GetCounterValue("System", "System Up Time", -1);
+        
+        etc ....
 
 =item $PerfObj->CollectData()
 
